@@ -1,6 +1,6 @@
 ;;;; This file is part of LilyPond, the GNU music typesetter.
 ;;;;
-;;;; Copyright (C) 2000--2012 Han-Wen Nienhuys <hanwen@xs4all.nl>
+;;;; Copyright (C) 2000--2020 Han-Wen Nienhuys <hanwen@xs4all.nl>
 ;;;;                 Jan Nieuwenhuizen <janneke@gnu.org>
 ;;;;
 ;;;; LilyPond is free software: you can redistribute it and/or modify
@@ -143,18 +143,18 @@
            (path (cdr args)))
 
         (string-append
-         "@item Set "
-         (format #f "grob-property @code{~a} "
-                 (string-join (map symbol->string path) " "))
-         (format #f "in @ref{~a} to ~a."
-                 context-sym (scm->texi value))
-         "\n")))
+         (format #f "@item Set grob-property @code{~{~a~^.~}} " path)
+         (format #f "in @ref{~a} to" context-sym)
+         (if (pretty-printable? value)
+             (format #f ":~a\n" (scm->texi value))
+             (format #f " ~a.\n" (scm->texi value))))))
      ((equal? (object-property context-sym 'is-grob?) #t) "")
      ((equal? tag 'assign)
-      (format #f "@item Set translator property @code{~a} to ~a.\n"
-              context-sym
-              (scm->texi (car args))))
-     )))
+      (string-append
+       (format #f "@item Set translator property @code{~a} to" context-sym)
+       (if (pretty-printable? (car args))
+           (format #f ":~a\n" (scm->texi (car args)))
+           (format #f " ~a.\n" (scm->texi (car args)))))))))
 
 
 (define (context-doc context-desc)
@@ -165,6 +165,7 @@
          (accepts (assoc-get 'accepts context-desc))
          (consists (assoc-get 'consists context-desc))
          (props (assoc-get 'property-ops context-desc))
+         (defaultchild (assoc-get 'default-child context-desc))
          (grobs  (context-grobs context-desc))
          (grob-refs (map ref-ify (sort grobs ly:string-ci<?))))
 
@@ -197,8 +198,13 @@
                   "@end itemize\n")))
            "")
 
+       (if defaultchild
+           (format #f "\n\nThis is not a `Bottom' context; search for such a one will commence after creating an implicit context of type @ref{~a}."
+                   defaultchild)
+           "\n\nThis is a `Bottom' context; no contexts will be created implicitly from it.")
+
        (if (null? accepts)
-           "\n\nThis context is a `bottom' context; it cannot contain other contexts."
+           "\n\nThis context cannot contain other contexts."
            (string-append
             "\n\nContext "
             name
