@@ -1,6 +1,6 @@
 ;;;; This file is part of LilyPond, the GNU music typesetter.
 ;;;;
-;;;; Copyright (C) 2004--2012 Jan Nieuwenhuizen <janneke@gnu.org>
+;;;; Copyright (C) 2004--2020 Jan Nieuwenhuizen <janneke@gnu.org>
 ;;;;          Han-Wen Nienhuys <hanwen@xs4all.nl>
 ;;;;
 ;;;; LilyPond is free software: you can redistribute it and/or modify
@@ -23,13 +23,13 @@
 
 ;;;;;;;;;;;;;;;;;;
 
-(define-public ((marked-up-headfoot what-odd what-even)
-                layout scopes page-number is-last-bookpart is-bookpart-last-page)
+(define ((marked-up-headfoot what-odd what-even)
+         layout scopes page-number is-last-bookpart is-bookpart-last-page)
   "Read variables @var{what-odd}, @var{what-even} from @var{layout},
 and interpret them as markup.  The @var{props} argument will include
 variables set in @var{scopes} and @code{page:is-bookpart-last-page},
 @code{page:is-last-bookpart}, @code{page:page-number-string}, and
-@code{page:page-number}."
+@code{page:page-number}. Returns a stencil."
 
   (define (get sym)
     (ly:output-def-lookup layout sym))
@@ -48,6 +48,7 @@ variables set in @var{scopes} and @code{page:is-bookpart-last-page},
                                (cdr entry)))
                             alist))
                      alists))
+               (number-type (get 'page-number-type))
                (pgnum-alist
                 (list
                  (cons 'header:tagline
@@ -56,7 +57,7 @@ variables set in @var{scopes} and @code{page:is-bookpart-last-page},
                  (cons 'page:is-last-bookpart is-last-bookpart)
                  (cons 'page:is-bookpart-last-page is-bookpart-last-page)
                  (cons 'page:page-number-string
-                       (number->string page-number))
+                       (number-format number-type page-number))
                  (cons 'page:page-number page-number)))
                (props (append
                        (list pgnum-alist)
@@ -72,7 +73,9 @@ variables set in @var{scopes} and @code{page:is-bookpart-last-page},
        (get what-even)
        (get what-odd))))
 
-(define-public ((marked-up-title what) layout scopes)
+(export marked-up-headfoot)
+
+(define ((marked-up-title what) layout scopes)
   "Read variables @var{what} from @var{scopes}, and interpret it as markup.
 The @var{props} argument will include variables set in @var{scopes} (prefixed
 with `header:'."
@@ -96,8 +99,9 @@ with `header:'."
          (props (append prefixed-alist
                         (layout-extract-page-properties layout)))
 
-         (markup (ly:output-def-lookup layout what)))
+         (title-markup (ly:output-def-lookup layout what)))
 
-    (if (markup? markup)
-        (interpret-markup layout props markup)
+    (if (markup? title-markup)
+        (interpret-markup layout props title-markup)
         empty-stencil)))
+(export marked-up-title)
